"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.common_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ScanPattern(google.protobuf.message.Message):
    """*
    The scan pattern defines the movement of the mirrors.
    The key parameters of the pattern are the horizontal and vertical fields of view (FoV) as well as the number of scan lines per frame.
    The frame rate is defined by the total number of scan lines and the oscillation frequency of the mirrors which is fixed and device-spcific.

    For a more detailed explanation, see: [Scan Pattern documentation](Scan_Pattern)
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Horizontal(google.protobuf.message.Message):
        """*
        This section defines the movement of the horizontal mirror.
        The mirror moves continuously with its own frequency. Each half-oscillation period of the mirror results in one scan line.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FOV_FIELD_NUMBER: builtins.int
        fov: builtins.float = ...
        """*
        Unit: [rad]
        –
        optical field of view of the horizontal mirror.
        Note: In v2.2* and below, this was defined as a mechanical FoV.
        """

        def __init__(self,
            *,
            fov : typing.Optional[builtins.float] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"fov",b"fov"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"fov",b"fov"]) -> None: ...

    class Vertical(google.protobuf.message.Message):
        """*
        This section defines the movement of the vertical mirror within one frame.
        The mirror moves for from 0 degrees to the configured target FoV (up-ramping phase) and back to 0 degrees (down-ramping phase) with its eigenfrequency.
        The number of scanlines for each phase can be configured.
        Due to the dynamics of the mirror, a certain number of scan lines are required to reach the target FoV and then to reach 0 degrees again.
        Consequently, if the limit is reached, a lower number of scan lines requires a reduced FoV.
        Thus, a higher number of scan lines allows a larger vertical FoV. The vertical FoV is limited by the optical components.

        Note: Due to the time required for one scan line, the rounded even number of scan lines directly scales inverse proportionally with65t the frame rate.

        For a more detailed explanation, see: [Scan Pattern documentation](Scan_Pattern)
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FOV_FIELD_NUMBER: builtins.int
        SCANLINES_UP_FIELD_NUMBER: builtins.int
        SCANLINES_DOWN_FIELD_NUMBER: builtins.int
        fov: builtins.float = ...
        """*
        Unit: [rad]
        –
        FoV in the center of the frame.
        Due to the eye shape of the scan pattern, the vertical FoV decreases the outer boundaries of the horizontal mirror.
        """

        scanlines_up: builtins.int = ...
        """*
        Configures the number of scan lines required for the up-ramping phase.
        During the up-ramping phase, the vertical mirror increases its amplitude from 0 degrees to the target FoV. Default: 200
        """

        scanlines_down: builtins.int = ...
        """*
        Configures the amount of scan lines required for the down-ramping phase.
        During the down-ramping phase, the vertical mirror decreases its amplitude from the target FoV to 0 degrees. Default: 30
        """

        def __init__(self,
            *,
            fov : typing.Optional[builtins.float] = ...,
            scanlines_up : typing.Optional[builtins.int] = ...,
            scanlines_down : typing.Optional[builtins.int] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"fov",b"fov",u"scanlines_down",b"scanlines_down",u"scanlines_up",b"scanlines_up"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"fov",b"fov",u"scanlines_down",b"scanlines_down",u"scanlines_up",b"scanlines_up"]) -> None: ...

    class Pulse(google.protobuf.message.Message):
        """*
        This section defines the pattern in which the laser pulses and captures sample points
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Type(_Type, metaclass=_TypeEnumTypeWrapper):
            """*
            The device pulses depending on the mirror positioning.
            Currently, only pulse triggering on the horizontal angle is supported.
            The laser pulses are emittet with the configured angular spacing.
            """
            pass
        class _Type:
            V = typing.NewType('V', builtins.int)
        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Type.V], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
            EQUI_HORIZONTAL_ANGLE = ScanPattern.Pulse.Type.V(0)
            """The laser is triggered depending on the horizontal angle of the laser beam with the configured angle spacing."""

            EQUI_DENSITY = ScanPattern.Pulse.Type.V(1)
            """Reserved for future use. Not yet supported."""

            CUSTOM = ScanPattern.Pulse.Type.V(2)
            """Internal feature for custom scan patterns"""

            INTERLEAVE = ScanPattern.Pulse.Type.V(3)
            """
            The laser is triggered depending on the horizontal angle of the laser beam with the configured angle spacing.
            Scanlines are shifted by angle_spacing/4 with alternate directions.
            This doubles the horizontal density with the COMBINE_UP_DOWN FrameMode and efficiently uses the down-ramp phase in the inner horizontal FoV.
            """


        EQUI_HORIZONTAL_ANGLE = ScanPattern.Pulse.Type.V(0)
        """The laser is triggered depending on the horizontal angle of the laser beam with the configured angle spacing."""

        EQUI_DENSITY = ScanPattern.Pulse.Type.V(1)
        """Reserved for future use. Not yet supported."""

        CUSTOM = ScanPattern.Pulse.Type.V(2)
        """Internal feature for custom scan patterns"""

        INTERLEAVE = ScanPattern.Pulse.Type.V(3)
        """
        The laser is triggered depending on the horizontal angle of the laser beam with the configured angle spacing.
        Scanlines are shifted by angle_spacing/4 with alternate directions.
        This doubles the horizontal density with the COMBINE_UP_DOWN FrameMode and efficiently uses the down-ramp phase in the inner horizontal FoV.
        """


        class FrameMode(_FrameMode, metaclass=_FrameModeEnumTypeWrapper):
            """*
            Because of the mirrors oscillating and the resulting Lissajous curve, it is not possible to pulse in a completely arbitrary pattern.
            A frame always starts with a phase in which the vertical mirror increases its amplitude (up-ramping).
            It is followed by a second phase, in which it decreases its amplitude until it no longer moves (down-ramping).
            It is possible to pulse in both phases. There are four different options to pulse:
            """
            pass
        class _FrameMode:
            V = typing.NewType('V', builtins.int)
        class _FrameModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FrameMode.V], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
            NONE = ScanPattern.Pulse.FrameMode.V(0)
            COMBINE_UP_DOWN = ScanPattern.Pulse.FrameMode.V(1)
            """*
            The device pulses in the up-ramping and down-ramping phases and one frame is created by combining the resulting sample points.
            """

            ONLY_UP = ScanPattern.Pulse.FrameMode.V(2)
            """*
            The device pulses in the **up-ramping** phase and **does not** pulse in the **down-ramping** phase.
            """

            ONLY_DOWN = ScanPattern.Pulse.FrameMode.V(3)
            """*
            The device is **does not** pulse in the **up-ramping** phase and pulses in the **down-ramping** phase.
            """

            SEPARATE = ScanPattern.Pulse.FrameMode.V(4)
            """*
            The device pulses in the up-ramping and down-ramping phases and one frame for each phase is created.
            """


        NONE = ScanPattern.Pulse.FrameMode.V(0)
        COMBINE_UP_DOWN = ScanPattern.Pulse.FrameMode.V(1)
        """*
        The device pulses in the up-ramping and down-ramping phases and one frame is created by combining the resulting sample points.
        """

        ONLY_UP = ScanPattern.Pulse.FrameMode.V(2)
        """*
        The device pulses in the **up-ramping** phase and **does not** pulse in the **down-ramping** phase.
        """

        ONLY_DOWN = ScanPattern.Pulse.FrameMode.V(3)
        """*
        The device is **does not** pulse in the **up-ramping** phase and pulses in the **down-ramping** phase.
        """

        SEPARATE = ScanPattern.Pulse.FrameMode.V(4)
        """*
        The device pulses in the up-ramping and down-ramping phases and one frame for each phase is created.
        """


        class Custom(google.protobuf.message.Message):
            """
            > Introduced in BSL v2.15 and firmware v1.16

            Custom scan pattern configuration. Required for different use cases, as e.g. angle triggers, point triggers, or detector recordings.
            """
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            class Trigger(_Trigger, metaclass=_TriggerEnumTypeWrapper):
                """
                List of available device triggers.
                """
                pass
            class _Trigger:
                V = typing.NewType('V', builtins.int)
            class _TriggerEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Trigger.V], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
                TRG_EXTERNAL_0 = ScanPattern.Pulse.Custom.Trigger.V(1)
                """External output pin, routed to TEST0 on the debug board."""

                TRG_EXTERNAL_1 = ScanPattern.Pulse.Custom.Trigger.V(2)
                """External output pin, routed to TEST1 on the debug board."""

                TRG_DETECTOR = ScanPattern.Pulse.Custom.Trigger.V(3)
                """Internal detector recording, which can retrieved with the detector stream."""

                TRG_LASER = ScanPattern.Pulse.Custom.Trigger.V(4)
                """Trigger laser."""


            TRG_EXTERNAL_0 = ScanPattern.Pulse.Custom.Trigger.V(1)
            """External output pin, routed to TEST0 on the debug board."""

            TRG_EXTERNAL_1 = ScanPattern.Pulse.Custom.Trigger.V(2)
            """External output pin, routed to TEST1 on the debug board."""

            TRG_DETECTOR = ScanPattern.Pulse.Custom.Trigger.V(3)
            """Internal detector recording, which can retrieved with the detector stream."""

            TRG_LASER = ScanPattern.Pulse.Custom.Trigger.V(4)
            """Trigger laser."""


            class Duration(google.protobuf.message.Message):
                """
                Specify duration for trigger type in seconds.
                """
                DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
                EXTERNAL_0_FIELD_NUMBER: builtins.int
                EXTERNAL_1_FIELD_NUMBER: builtins.int
                external_0: builtins.float = ...
                """in [s]"""

                external_1: builtins.float = ...
                """in [s]"""

                def __init__(self,
                    *,
                    external_0 : typing.Optional[builtins.float] = ...,
                    external_1 : typing.Optional[builtins.float] = ...,
                    ) -> None: ...
                def HasField(self, field_name: typing_extensions.Literal[u"external_0",b"external_0",u"external_1",b"external_1"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing_extensions.Literal[u"external_0",b"external_0",u"external_1",b"external_1"]) -> None: ...

            class AngleTrigger(google.protobuf.message.Message):
                """
                Allows to trigger based on horizontal angles.
                """
                DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
                class Angle(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
                    HORIZONTAL_ANGLE_FIELD_NUMBER: builtins.int
                    SCANLINE_ID_FIELD_NUMBER: builtins.int
                    ENABLED_TRIGGERS_FIELD_NUMBER: builtins.int
                    horizontal_angle: builtins.float = ...
                    """in [rad]"""

                    scanline_id: builtins.int = ...
                    """Define in which scanline the trigger should occur, if none is given, it will trigger in all scanlines"""

                    @property
                    def enabled_triggers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___ScanPattern.Pulse.Custom.Trigger.V]: ...
                    def __init__(self,
                        *,
                        horizontal_angle : typing.Optional[builtins.float] = ...,
                        scanline_id : typing.Optional[builtins.int] = ...,
                        enabled_triggers : typing.Optional[typing.Iterable[global___ScanPattern.Pulse.Custom.Trigger.V]] = ...,
                        ) -> None: ...
                    def HasField(self, field_name: typing_extensions.Literal[u"horizontal_angle",b"horizontal_angle",u"scanline_id",b"scanline_id"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing_extensions.Literal[u"enabled_triggers",b"enabled_triggers",u"horizontal_angle",b"horizontal_angle",u"scanline_id",b"scanline_id"]) -> None: ...

                ANGLES_FIELD_NUMBER: builtins.int
                @property
                def angles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScanPattern.Pulse.Custom.AngleTrigger.Angle]:
                    """List of angles"""
                    pass
                def __init__(self,
                    *,
                    angles : typing.Optional[typing.Iterable[global___ScanPattern.Pulse.Custom.AngleTrigger.Angle]] = ...,
                    ) -> None: ...
                def ClearField(self, field_name: typing_extensions.Literal[u"angles",b"angles"]) -> None: ...

            class PointTrigger(google.protobuf.message.Message):
                """
                Set point triggers for the normal equi-distant horizontal scan pattern.
                """
                DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
                class Point(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
                    ID_FIELD_NUMBER: builtins.int
                    ENABLED_TRIGGERS_FIELD_NUMBER: builtins.int
                    id: builtins.int = ...
                    """Define which point ID should be triggered"""

                    @property
                    def enabled_triggers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___ScanPattern.Pulse.Custom.Trigger.V]: ...
                    def __init__(self,
                        *,
                        id : typing.Optional[builtins.int] = ...,
                        enabled_triggers : typing.Optional[typing.Iterable[global___ScanPattern.Pulse.Custom.Trigger.V]] = ...,
                        ) -> None: ...
                    def HasField(self, field_name: typing_extensions.Literal[u"id",b"id"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing_extensions.Literal[u"enabled_triggers",b"enabled_triggers",u"id",b"id"]) -> None: ...

                POINTS_FIELD_NUMBER: builtins.int
                @property
                def points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScanPattern.Pulse.Custom.PointTrigger.Point]: ...
                def __init__(self,
                    *,
                    points : typing.Optional[typing.Iterable[global___ScanPattern.Pulse.Custom.PointTrigger.Point]] = ...,
                    ) -> None: ...
                def ClearField(self, field_name: typing_extensions.Literal[u"points",b"points"]) -> None: ...

            ANGLE_TRIGGER_FIELD_NUMBER: builtins.int
            POINT_TRIGGER_FIELD_NUMBER: builtins.int
            DURATION_FIELD_NUMBER: builtins.int
            @property
            def angle_trigger(self) -> global___ScanPattern.Pulse.Custom.AngleTrigger: ...
            @property
            def point_trigger(self) -> global___ScanPattern.Pulse.Custom.PointTrigger: ...
            @property
            def duration(self) -> global___ScanPattern.Pulse.Custom.Duration: ...
            def __init__(self,
                *,
                angle_trigger : typing.Optional[global___ScanPattern.Pulse.Custom.AngleTrigger] = ...,
                point_trigger : typing.Optional[global___ScanPattern.Pulse.Custom.PointTrigger] = ...,
                duration : typing.Optional[global___ScanPattern.Pulse.Custom.Duration] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"angle_trigger",b"angle_trigger",u"custom_type",b"custom_type",u"duration",b"duration",u"point_trigger",b"point_trigger"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"angle_trigger",b"angle_trigger",u"custom_type",b"custom_type",u"duration",b"duration",u"point_trigger",b"point_trigger"]) -> None: ...
            def WhichOneof(self, oneof_group: typing_extensions.Literal[u"custom_type",b"custom_type"]) -> typing.Optional[typing_extensions.Literal["angle_trigger","point_trigger"]]: ...

        ANGLE_SPACING_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        FRAME_MODE_FIELD_NUMBER: builtins.int
        DISTORTION_CORRECTION_FIELD_NUMBER: builtins.int
        CUSTOM_FIELD_NUMBER: builtins.int
        angle_spacing: builtins.float = ...
        """*
        Unit: [rad]
        –
        This defines the angle within which the horizontal mirror moves between two laser pulses.
        This parameter therefore defines the horizontal sampling resolution.
        """

        type: global___ScanPattern.Pulse.Type.V = ...
        """Refer to [ScanPattern.Pulse.Type](#blickfeld.protocol.config.ScanPattern.Pulse.Type)"""

        frame_mode: global___ScanPattern.Pulse.FrameMode.V = ...
        """Refer to [ScanPattern.Pulse.FrameMode](#blickfeld.protocol.config.ScanPattern.Pulse.FrameMode)"""

        distortion_correction: builtins.bool = ...
        """*
        This parameter defines whether the distortion correction is applied when calculating the laser pulse angles. Default: True
        """

        @property
        def custom(self) -> global___ScanPattern.Pulse.Custom:
            """<blockquote>Introduced in BSL v2.15 and firmware v1.16</blockquote> Refer to [ScanPattern.Pulse.Custom](#blickfeld.protocol.config.ScanPattern.Pulse.Custom)"""
            pass
        def __init__(self,
            *,
            angle_spacing : typing.Optional[builtins.float] = ...,
            type : typing.Optional[global___ScanPattern.Pulse.Type.V] = ...,
            frame_mode : typing.Optional[global___ScanPattern.Pulse.FrameMode.V] = ...,
            distortion_correction : typing.Optional[builtins.bool] = ...,
            custom : typing.Optional[global___ScanPattern.Pulse.Custom] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"angle_spacing",b"angle_spacing",u"custom",b"custom",u"distortion_correction",b"distortion_correction",u"frame_mode",b"frame_mode",u"type",b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"angle_spacing",b"angle_spacing",u"custom",b"custom",u"distortion_correction",b"distortion_correction",u"frame_mode",b"frame_mode",u"type",b"type"]) -> None: ...

    class FrameRate(google.protobuf.message.Message):
        """*
        This section defines the target frame rate for synchronization between several LiDAR devices.
        The feature is described in the [Time synchronization documentation](Sync).
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TARGET_FIELD_NUMBER: builtins.int
        MAXIMUM_FIELD_NUMBER: builtins.int
        REFERENCE_TIME_OFFSET_FIELD_NUMBER: builtins.int
        target: builtins.float = ...
        """Target frame rate during synchronization between several LiDAR devices"""

        maximum: builtins.float = ...
        """Read-only parameter for maximum achievable frame rate."""

        reference_time_offset: builtins.float = ...
        """*
        In [s]. Adds a constant value to the Unix reference time, starting from 00:00:00 UTC on January 1, 1970.
        It can be used to compensate delays or to interleave LiDAR devices. Default: 0
        """

        def __init__(self,
            *,
            target : typing.Optional[builtins.float] = ...,
            maximum : typing.Optional[builtins.float] = ...,
            reference_time_offset : typing.Optional[builtins.float] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"reference_time_offset",b"reference_time_offset",u"target",b"target"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"reference_time_offset",b"reference_time_offset",u"target",b"target"]) -> None: ...

    class Filter(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.10 and firmware v1.9

        Filter points and returns by point attributes during the post-processing on the device.
        This can be used to e.g. filter points with low intensity or to enable secondary returns.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Noise(google.protobuf.message.Message):
            """*
            > Introduced in BSL v2.11 and firmware v1.11

            This is a preliminary interface to control the noise filter on the device.
            All points, which have a lower intensity than the minimum intensity calculated by this filter will be filtered out.

            > Changed in firmware v1.15. Please re-adjust filter configurations in scan patterns.

            The internal algorithm implements a non-linear function, which describes the noise level for different ambient light levels.
            The function can be scaled with the gain and shifted with the offset.

            > Before firmware v1.15

            The formula is: minimum_intensity = offset + gain * point.ambient_light_level,
            where the point.ambient_light_level is the ambient light level of the point the laser shoots at.
            """
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            OFFSET_FIELD_NUMBER: builtins.int
            GAIN_FIELD_NUMBER: builtins.int
            ENABLE_FIELD_NUMBER: builtins.int
            offset: builtins.int = ...
            """Can be seen as minimum intensity filter, if there is no ambient light."""

            gain: builtins.float = ...
            """The gain scales a non-linear function, which uses the ambient light level of the point the laser shoots at, as an input."""

            enable: builtins.bool = ...
            """<blockquote>Introduced in BSL v2.17 and firmware v1.18</blockquote>	This flag can be used to disable the internal noise filter completely. By default, the noise filter is enabled."""

            def __init__(self,
                *,
                offset : typing.Optional[builtins.int] = ...,
                gain : typing.Optional[builtins.float] = ...,
                enable : typing.Optional[builtins.bool] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"enable",b"enable",u"gain",b"gain",u"offset",b"offset"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"enable",b"enable",u"gain",b"gain",u"offset",b"offset"]) -> None: ...

        MAX_NUMBER_OF_RETURNS_PER_POINT_FIELD_NUMBER: builtins.int
        INTENSITY_FIELD_NUMBER: builtins.int
        AMBIENT_LIGHT_LEVEL_FIELD_NUMBER: builtins.int
        RANGE_FIELD_NUMBER: builtins.int
        NOISE_FIELD_NUMBER: builtins.int
        DELETE_POINTS_WITHOUT_RETURNS_FIELD_NUMBER: builtins.int
        max_number_of_returns_per_point: builtins.int = ...
        """Set maximum number of returns per point. By default, secondary returns are disabled. Set this, e.g. to 2, to enable secondary returns."""

        @property
        def intensity(self) -> blickfeld.common_pb2.OptionalValueRange:
            """Filter all points, which intensity values are not within this value range."""
            pass
        @property
        def ambient_light_level(self) -> blickfeld.common_pb2.OptionalValueRange:
            """Filter all points, which ambient light level values are not within this value range."""
            pass
        @property
        def range(self) -> blickfeld.common_pb2.OptionalValueRange:
            """Filter all points, which range values are not within this value range."""
            pass
        @property
        def noise(self) -> global___ScanPattern.Filter.Noise:
            """<blockquote>Introduced in BSL v2.11 and firmware v1.11</blockquote> Refer to [Filter.Noise](#blickfeld.protocol.config.ScanPattern.Filter.Noise)"""
            pass
        delete_points_without_returns: builtins.bool = ...
        """
        <blockquote> Introduced in BSL v2.16 and firmware v1.17</blockquote>
        All points without any returns are filtered if this setting is true.
        With active algorithms, such as background subtraction, this can reduce the bandwidth significantly.
        <br>
        Note:
        It is recommended to not estimate required network bandwidths when this setting is active.
        In scenarios, where from one frame to another, all points have returns (e.g. due to environmental changes),
        the peak bandwidths might increase significantly. This could result, in these scenarios, in frame losses.
        """

        def __init__(self,
            *,
            max_number_of_returns_per_point : typing.Optional[builtins.int] = ...,
            intensity : typing.Optional[blickfeld.common_pb2.OptionalValueRange] = ...,
            ambient_light_level : typing.Optional[blickfeld.common_pb2.OptionalValueRange] = ...,
            range : typing.Optional[blickfeld.common_pb2.OptionalValueRange] = ...,
            noise : typing.Optional[global___ScanPattern.Filter.Noise] = ...,
            delete_points_without_returns : typing.Optional[builtins.bool] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"ambient_light_level",b"ambient_light_level",u"delete_points_without_returns",b"delete_points_without_returns",u"intensity",b"intensity",u"max_number_of_returns_per_point",b"max_number_of_returns_per_point",u"noise",b"noise",u"range",b"range"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"ambient_light_level",b"ambient_light_level",u"delete_points_without_returns",b"delete_points_without_returns",u"intensity",b"intensity",u"max_number_of_returns_per_point",b"max_number_of_returns_per_point",u"noise",b"noise",u"range",b"range"]) -> None: ...

    HORIZONTAL_FIELD_NUMBER: builtins.int
    VERTICAL_FIELD_NUMBER: builtins.int
    PULSE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    CONSTRAINTS_FIELD_NUMBER: builtins.int
    @property
    def horizontal(self) -> global___ScanPattern.Horizontal:
        """Refer to [ScanPattern.Horizontal](#blickfeld.protocol.config.ScanPattern.Horizontal)"""
        pass
    @property
    def vertical(self) -> global___ScanPattern.Vertical:
        """Refer to [ScanPattern.Vertical](#blickfeld.protocol.config.ScanPattern.Vertical)"""
        pass
    @property
    def pulse(self) -> global___ScanPattern.Pulse:
        """Refer to [ScanPattern.Pulse](#blickfeld.protocol.config.ScanPattern.Pulse)"""
        pass
    @property
    def frame_rate(self) -> global___ScanPattern.FrameRate:
        """Refer to [ScanPattern.FrameRate](#blickfeld.protocol.config.ScanPattern.FrameRate)"""
        pass
    @property
    def filter(self) -> global___ScanPattern.Filter:
        """<blockquote>Introduced in BSL v2.11 and firmware v1.11</blockquote> Refer to [Filter](#blickfeld.protocol.config.ScanPattern.Filter)"""
        pass
    @property
    def constraints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.common_pb2.Constraint]: ...
    def __init__(self,
        *,
        horizontal : typing.Optional[global___ScanPattern.Horizontal] = ...,
        vertical : typing.Optional[global___ScanPattern.Vertical] = ...,
        pulse : typing.Optional[global___ScanPattern.Pulse] = ...,
        frame_rate : typing.Optional[global___ScanPattern.FrameRate] = ...,
        filter : typing.Optional[global___ScanPattern.Filter] = ...,
        constraints : typing.Optional[typing.Iterable[blickfeld.common_pb2.Constraint]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"filter",b"filter",u"frame_rate",b"frame_rate",u"horizontal",b"horizontal",u"pulse",b"pulse",u"vertical",b"vertical"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"constraints",b"constraints",u"filter",b"filter",u"frame_rate",b"frame_rate",u"horizontal",b"horizontal",u"pulse",b"pulse",u"vertical",b"vertical"]) -> None: ...
global___ScanPattern = ScanPattern



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class State(google.protobuf.message.Message):
    """*
    A state transmits high-level information about the scene.
    States will get calculated on every frame of measurement.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Counter(google.protobuf.message.Message):
        """*
        A message containing a count for certain scenarios at a certain timestamp.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Type(_Type, metaclass=_TypeEnumTypeWrapper):
            pass
        class _Type:
            V = typing.NewType('V', builtins.int)
        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Type.V], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
            INBOUND = State.Counter.Type.V(0)
            """used for counting entries"""

            OUTBOUND = State.Counter.Type.V(1)
            """used for counting exists"""

            INSIDE = State.Counter.Type.V(2)
            """used for counting the current number of objects"""


        INBOUND = State.Counter.Type.V(0)
        """used for counting entries"""

        OUTBOUND = State.Counter.Type.V(1)
        """used for counting exists"""

        INSIDE = State.Counter.Type.V(2)
        """used for counting the current number of objects"""


        COUNT_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        OBJECT_UUIDS_FIELD_NUMBER: builtins.int
        count: builtins.int = ...
        """The value of the counter."""

        type: global___State.Counter.Type.V = ...
        """Type of the counter."""

        @property
        def object_uuids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
            """The uuids of the counted objects"""
            pass
        def __init__(self,
            *,
            count : builtins.int = ...,
            type : global___State.Counter.Type.V = ...,
            object_uuids : typing.Optional[typing.Iterable[typing.Text]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"count",b"count",u"object_uuids",b"object_uuids",u"type",b"type"]) -> None: ...

    class AccumulatedCounter(google.protobuf.message.Message):
        """*
        A message containing an accumulating count for certain scenario since a start timestamp.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Type(_Type, metaclass=_TypeEnumTypeWrapper):
            pass
        class _Type:
            V = typing.NewType('V', builtins.int)
        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Type.V], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
            INBOUND = State.AccumulatedCounter.Type.V(0)
            """used for counting entries"""

            OUTBOUND = State.AccumulatedCounter.Type.V(1)
            """used for counting exists"""


        INBOUND = State.AccumulatedCounter.Type.V(0)
        """used for counting entries"""

        OUTBOUND = State.AccumulatedCounter.Type.V(1)
        """used for counting exists"""


        COUNT_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        START_OF_COUNT_FIELD_NUMBER: builtins.int
        count: builtins.int = ...
        """A counter which increases over time starting at '0' at 'start_of_count'. The 'count' and
        'start_of_count' is automatically in certain intervals to prevent integer overflows.
        """

        type: global___State.AccumulatedCounter.Type.V = ...
        """Type of the counter"""

        @property
        def start_of_count(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(self,
            *,
            count : builtins.int = ...,
            type : global___State.AccumulatedCounter.Type.V = ...,
            start_of_count : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"start_of_count",b"start_of_count"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"count",b"count",u"start_of_count",b"start_of_count",u"type",b"type"]) -> None: ...

    class Security(google.protobuf.message.Message):
        """*
        A message containing an alarm state of a zone.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ALARM_FIELD_NUMBER: builtins.int
        NUM_DETECTED_POINTS_FIELD_NUMBER: builtins.int
        alarm: builtins.bool = ...
        num_detected_points: builtins.int = ...
        """The current number of lidar points detected the zone"""

        def __init__(self,
            *,
            alarm : builtins.bool = ...,
            num_detected_points : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"alarm",b"alarm",u"num_detected_points",b"num_detected_points"]) -> None: ...

    class Occupancy(google.protobuf.message.Message):
        """*
        A message containing the occupancy state of a zone.
        This is based on one occupancy zone or a row occupancy zones.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        OCCUPIED_FIELD_NUMBER: builtins.int
        NUM_DETECTED_POINTS_FIELD_NUMBER: builtins.int
        occupied: builtins.bool = ...
        num_detected_points: builtins.int = ...
        """The current number of lidar points detected the zone"""

        def __init__(self,
            *,
            occupied : builtins.bool = ...,
            num_detected_points : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"num_detected_points",b"num_detected_points",u"occupied",b"occupied"]) -> None: ...

    class Volume(google.protobuf.message.Message):
        """*
        A message containing the volume state of a zone.
        This is based on one volume zone.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        VOLUME_FIELD_NUMBER: builtins.int
        volume: builtins.float = ...
        """The current volume of the zone"""

        def __init__(self,
            *,
            volume : builtins.float = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"volume",b"volume"]) -> None: ...

    TIMESTAMP_FIELD_NUMBER: builtins.int
    ZONE_ALGORITHM_UUID_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    ACCUMULATED_COUNTER_FIELD_NUMBER: builtins.int
    SECURITY_FIELD_NUMBER: builtins.int
    OCCUPANCY_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the lidar frame in which the state was measured"""
        pass
    zone_algorithm_uuid: typing.Text = ...
    """The uuid of the zone algorithm generating this state"""

    @property
    def counter(self) -> global___State.Counter: ...
    @property
    def accumulated_counter(self) -> global___State.AccumulatedCounter: ...
    @property
    def security(self) -> global___State.Security: ...
    @property
    def occupancy(self) -> global___State.Occupancy: ...
    @property
    def volume(self) -> global___State.Volume: ...
    def __init__(self,
        *,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        zone_algorithm_uuid : typing.Text = ...,
        counter : typing.Optional[global___State.Counter] = ...,
        accumulated_counter : typing.Optional[global___State.AccumulatedCounter] = ...,
        security : typing.Optional[global___State.Security] = ...,
        occupancy : typing.Optional[global___State.Occupancy] = ...,
        volume : typing.Optional[global___State.Volume] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"accumulated_counter",b"accumulated_counter",u"counter",b"counter",u"occupancy",b"occupancy",u"security",b"security",u"state_type",b"state_type",u"timestamp",b"timestamp",u"volume",b"volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"accumulated_counter",b"accumulated_counter",u"counter",b"counter",u"occupancy",b"occupancy",u"security",b"security",u"state_type",b"state_type",u"timestamp",b"timestamp",u"volume",b"volume",u"zone_algorithm_uuid",b"zone_algorithm_uuid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"state_type",b"state_type"]) -> typing.Optional[typing_extensions.Literal["counter","accumulated_counter","security","occupancy","volume"]]: ...
global___State = State



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HardwareVariant(_HardwareVariant, metaclass=_HardwareVariantEnumTypeWrapper):
    """do NOT change enum labels, they are used as strings in code"""
    pass
class _HardwareVariant:
    V = typing.NewType('V', builtins.int)
class _HardwareVariantEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HardwareVariant.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    ALL_HARDWARE = HardwareVariant.V(5)
    UNKNOWN_HARDWARE = HardwareVariant.V(6)
    NO_HARDWARE = HardwareVariant.V(7)
    CUBE_V0_2 = HardwareVariant.V(0)
    CUBE_V0_3 = HardwareVariant.V(1)
    CUBE_V1_0 = HardwareVariant.V(4)
    AURORA_P3 = HardwareVariant.V(3)
    APOLLON_A0 = HardwareVariant.V(2)
    APOLLON_A1_BDU = HardwareVariant.V(8)

ALL_HARDWARE = HardwareVariant.V(5)
UNKNOWN_HARDWARE = HardwareVariant.V(6)
NO_HARDWARE = HardwareVariant.V(7)
CUBE_V0_2 = HardwareVariant.V(0)
CUBE_V0_3 = HardwareVariant.V(1)
CUBE_V1_0 = HardwareVariant.V(4)
AURORA_P3 = HardwareVariant.V(3)
APOLLON_A0 = HardwareVariant.V(2)
APOLLON_A1_BDU = HardwareVariant.V(8)
global___HardwareVariant = HardwareVariant


class partial_trenz_eeprom_msg(google.protobuf.message.Message):
    """partial parse of trenz_eeprom_msg"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HARDWARE_VARIANT_FIELD_NUMBER: builtins.int
    hardware_variant: global___HardwareVariant.V = ...
    def __init__(self,
        *,
        hardware_variant : typing.Optional[global___HardwareVariant.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"hardware_variant",b"hardware_variant"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hardware_variant",b"hardware_variant"]) -> None: ...
global___partial_trenz_eeprom_msg = partial_trenz_eeprom_msg

class partial_module_eeprom_msg(google.protobuf.message.Message):
    """partial parse of {ldm,scanner,msb}_eeprom_msg"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HARDWARE_VERSION_FIELD_NUMBER: builtins.int
    hardware_version: typing.Text = ...
    def __init__(self,
        *,
        hardware_version : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"hardware_version",b"hardware_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hardware_version",b"hardware_version"]) -> None: ...
global___partial_module_eeprom_msg = partial_module_eeprom_msg



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/config/scan_pattern.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import common_pb2 as blickfeld_dot_common__pb2
from blickfeld import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/config/scan_pattern.proto',
  package='blickfeld.protocol.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#blickfeld/config/scan_pattern.proto\x12\x19\x62lickfeld.protocol.config\x1a\x16\x62lickfeld/common.proto\x1a\x17\x62lickfeld/options.proto\"\xad\x15\n\x0bScanPattern\x12\x45\n\nhorizontal\x18\x01 \x01(\x0b\x32\x31.blickfeld.protocol.config.ScanPattern.Horizontal\x12\x41\n\x08vertical\x18\x02 \x01(\x0b\x32/.blickfeld.protocol.config.ScanPattern.Vertical\x12;\n\x05pulse\x18\x03 \x01(\x0b\x32,.blickfeld.protocol.config.ScanPattern.Pulse\x12\x44\n\nframe_rate\x18\x04 \x01(\x0b\x32\x30.blickfeld.protocol.config.ScanPattern.FrameRate\x12=\n\x06\x66ilter\x18\x07 \x01(\x0b\x32-.blickfeld.protocol.config.ScanPattern.Filter\x12\x33\n\x0b\x63onstraints\x18\x08 \x03(\x0b\x32\x1e.blickfeld.protocol.Constraint\x1a\x38\n\nHorizontal\x12*\n\x03\x66ov\x18\x01 \x01(\x02\x42\x1d\xda\xb5\x18\x03rad\xe2\xb5\x18\x03\x64\x65g\xe9\xb5\x18\xb6\x94\x63\x1a\xdc\xa5L@\xf0\xb5\x18\x02\x1a\x86\x01\n\x08Vertical\x12*\n\x03\x66ov\x18\x01 \x01(\x02\x42\x1d\xda\xb5\x18\x03rad\xe2\xb5\x18\x03\x64\x65g\xe9\xb5\x18\xb6\x94\x63\x1a\xdc\xa5L@\xf0\xb5\x18\x02\x12%\n\x0cscanlines_up\x18\x02 \x01(\r:\x02\x34\x30\x42\x0b\x81\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?\x12\'\n\x0escanlines_down\x18\x03 \x01(\r:\x02\x34\x30\x42\x0b\x81\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?\x1a\xd5\x0b\n\x05Pulse\x12\x34\n\rangle_spacing\x18\x02 \x01(\x02\x42\x1d\xda\xb5\x18\x03rad\xe2\xb5\x18\x03\x64\x65g\xe9\xb5\x18\xb6\x94\x63\x1a\xdc\xa5L@\xf0\xb5\x18\x02\x12K\n\x04type\x18\x03 \x01(\x0e\x32\x31.blickfeld.protocol.config.ScanPattern.Pulse.Type:\nINTERLEAVE\x12[\n\nframe_mode\x18\x04 \x01(\x0e\x32\x36.blickfeld.protocol.config.ScanPattern.Pulse.FrameMode:\x0f\x43OMBINE_UP_DOWN\x12#\n\x15\x64istortion_correction\x18\x05 \x01(\x08:\x04true\x12I\n\x06\x63ustom\x18\x08 \x01(\x0b\x32\x33.blickfeld.protocol.config.ScanPattern.Pulse.CustomB\x04\xb0\xb5\x18\x01\x1a\xb9\x07\n\x06\x43ustom\x12Y\n\rangle_trigger\x18\x01 \x01(\x0b\x32@.blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTriggerH\x00\x12Y\n\rpoint_trigger\x18\x02 \x01(\x0b\x32@.blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTriggerH\x00\x12N\n\x08\x64uration\x18\x03 \x01(\x0b\x32<.blickfeld.protocol.config.ScanPattern.Pulse.Custom.Duration\x1ar\n\x08\x44uration\x12\x32\n\nexternal_0\x18\x01 \x01(\x02:\x06\x30.0001B\x16\x81\xb5\x18\x95\xd6&\xe8\x0b.A>\x89\xb5\x18\x9a\x99\x99\x99\x99\x99\xb9?\x12\x32\n\nexternal_1\x18\x02 \x01(\x02:\x06\x30.0001B\x16\x81\xb5\x18\x95\xd6&\xe8\x0b.A>\x89\xb5\x18\x9a\x99\x99\x99\x99\x99\xb9?\x1a\xfc\x01\n\x0c\x41ngleTrigger\x12V\n\x06\x61ngles\x18\x01 \x03(\x0b\x32\x46.blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger.Angle\x1a\x93\x01\n\x05\x41ngle\x12\x18\n\x10horizontal_angle\x18\x01 \x01(\x02\x12\x19\n\x0bscanline_id\x18\x02 \x01(\x04\x42\x04\xb0\xb5\x18\x01\x12U\n\x10\x65nabled_triggers\x18\x03 \x03(\x0e\x32;.blickfeld.protocol.config.ScanPattern.Pulse.Custom.Trigger\x1a\xd2\x01\n\x0cPointTrigger\x12V\n\x06points\x18\x01 \x03(\x0b\x32\x46.blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTrigger.Point\x1aj\n\x05Point\x12\n\n\x02id\x18\x01 \x01(\x04\x12U\n\x10\x65nabled_triggers\x18\x02 \x03(\x0e\x32;.blickfeld.protocol.config.ScanPattern.Pulse.Custom.Trigger\"R\n\x07Trigger\x12\x12\n\x0eTRG_EXTERNAL_0\x10\x01\x12\x12\n\x0eTRG_EXTERNAL_1\x10\x02\x12\x10\n\x0cTRG_DETECTOR\x10\x03\x12\r\n\tTRG_LASER\x10\x04\x42\r\n\x0b\x63ustom_type\"O\n\x04Type\x12\x19\n\x15\x45QUI_HORIZONTAL_ANGLE\x10\x00\x12\x10\n\x0c\x45QUI_DENSITY\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\x12\x0e\n\nINTERLEAVE\x10\x03\"T\n\tFrameMode\x12\x08\n\x04NONE\x10\x00\x12\x13\n\x0f\x43OMBINE_UP_DOWN\x10\x01\x12\x0b\n\x07ONLY_UP\x10\x02\x12\r\n\tONLY_DOWN\x10\x03\x12\x0c\n\x08SEPARATE\x10\x04*\x04\x08\x01\x10\x02*\x04\x08\x06\x10\x07*\x04\x08\x07\x10\x08R\x07padding\x1a\x8a\x01\n\tFrameRate\x12\x1e\n\x06target\x18\x01 \x01(\x01\x42\x0e\xda\xb5\x18\x02Hz\xf0\xb5\x18\x02\xb0\xb5\x18\x01\x12\x1f\n\x07maximum\x18\x02 \x01(\x01\x42\x0e\xda\xb5\x18\x02Hz\xf0\xb5\x18\x02\xb0\xb5\x18\x01\x12<\n\x15reference_time_offset\x18\x03 \x01(\x01:\x01\x30\x42\x1a\xda\xb5\x18\x01s\xe2\xb5\x18\x02ms\xf0\xb5\x18\x01\xe9\xb5\x18\xfc\xa9\xf1\xd2MbP?\x1a\xe8\x03\n\x06\x46ilter\x12\x42\n\x1fmax_number_of_returns_per_point\x18\x01 \x01(\r:\x01\x31\x42\x16\x81\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?\x89\xb5\x18\x00\x00\x00\x00\x00\x00\x08@\x12\x39\n\tintensity\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.OptionalValueRange\x12\x43\n\x13\x61mbient_light_level\x18\x03 \x01(\x0b\x32&.blickfeld.protocol.OptionalValueRange\x12\x35\n\x05range\x18\x04 \x01(\x0b\x32&.blickfeld.protocol.OptionalValueRange\x12H\n\x05noise\x18\x05 \x01(\x0b\x32\x33.blickfeld.protocol.config.ScanPattern.Filter.NoiseB\x04\xb0\xb5\x18\x01\x12,\n\x1d\x64\x65lete_points_without_returns\x18\x06 \x01(\x08:\x05\x66\x61lse\x1ak\n\x05Noise\x12&\n\x06offset\x18\x01 \x01(\rB\x16\x81\xb5\x18\x00\x00\x00\x00\x00\x00\x00\x00\x89\xb5\x18\x00\x00\x00\x00\x00\x00I@\x12$\n\x04gain\x18\x02 \x01(\x02\x42\x16\x81\xb5\x18\x00\x00\x00\x00\x00\x00\x00\x00\x89\xb5\x18\x00\x00\x00\x00\x00\x00\xe0?\x12\x14\n\x06\x65nable\x18\x03 \x01(\x08:\x04true*\x04\x08\x05\x10\x06*\x04\x08\x06\x10\x07'
  ,
  dependencies=[blickfeld_dot_common__pb2.DESCRIPTOR,blickfeld_dot_options__pb2.DESCRIPTOR,])



_SCANPATTERN_PULSE_CUSTOM_TRIGGER = _descriptor.EnumDescriptor(
  name='Trigger',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.Trigger',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRG_EXTERNAL_0', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRG_EXTERNAL_1', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRG_DETECTOR', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRG_LASER', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1914,
  serialized_end=1996,
)
_sym_db.RegisterEnumDescriptor(_SCANPATTERN_PULSE_CUSTOM_TRIGGER)

_SCANPATTERN_PULSE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUI_HORIZONTAL_ANGLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUI_DENSITY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERLEAVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2013,
  serialized_end=2092,
)
_sym_db.RegisterEnumDescriptor(_SCANPATTERN_PULSE_TYPE)

_SCANPATTERN_PULSE_FRAMEMODE = _descriptor.EnumDescriptor(
  name='FrameMode',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.FrameMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMBINE_UP_DOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONLY_UP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONLY_DOWN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEPARATE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2094,
  serialized_end=2178,
)
_sym_db.RegisterEnumDescriptor(_SCANPATTERN_PULSE_FRAMEMODE)


_SCANPATTERN_HORIZONTAL = _descriptor.Descriptor(
  name='Horizontal',
  full_name='blickfeld.protocol.config.ScanPattern.Horizontal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fov', full_name='blickfeld.protocol.config.ScanPattern.Horizontal.fov', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\030\003rad\342\265\030\003deg\351\265\030\266\224c\032\334\245L@\360\265\030\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=516,
  serialized_end=572,
)

_SCANPATTERN_VERTICAL = _descriptor.Descriptor(
  name='Vertical',
  full_name='blickfeld.protocol.config.ScanPattern.Vertical',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fov', full_name='blickfeld.protocol.config.ScanPattern.Vertical.fov', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\030\003rad\342\265\030\003deg\351\265\030\266\224c\032\334\245L@\360\265\030\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scanlines_up', full_name='blickfeld.protocol.config.ScanPattern.Vertical.scanlines_up', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=40,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\000\000\000\000\000\000\360?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scanlines_down', full_name='blickfeld.protocol.config.ScanPattern.Vertical.scanlines_down', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=40,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\000\000\000\000\000\000\360?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=709,
)

_SCANPATTERN_PULSE_CUSTOM_DURATION = _descriptor.Descriptor(
  name='Duration',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.Duration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_0', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.Duration.external_0', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.0001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\225\326&\350\013.A>\211\265\030\232\231\231\231\231\231\271?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_1', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.Duration.external_1', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.0001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\225\326&\350\013.A>\211\265\030\232\231\231\231\231\231\271?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1330,
  serialized_end=1444,
)

_SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER_ANGLE = _descriptor.Descriptor(
  name='Angle',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger.Angle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontal_angle', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger.Angle.horizontal_angle', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scanline_id', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger.Angle.scanline_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled_triggers', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger.Angle.enabled_triggers', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1552,
  serialized_end=1699,
)

_SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER = _descriptor.Descriptor(
  name='AngleTrigger',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='angles', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger.angles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER_ANGLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1699,
)

_SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTrigger.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTrigger.Point.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled_triggers', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTrigger.Point.enabled_triggers', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1912,
)

_SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER = _descriptor.Descriptor(
  name='PointTrigger',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTrigger.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER_POINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1912,
)

_SCANPATTERN_PULSE_CUSTOM = _descriptor.Descriptor(
  name='Custom',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle_trigger', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.angle_trigger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_trigger', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.point_trigger', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCANPATTERN_PULSE_CUSTOM_DURATION, _SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER, _SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER, ],
  enum_types=[
    _SCANPATTERN_PULSE_CUSTOM_TRIGGER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='custom_type', full_name='blickfeld.protocol.config.ScanPattern.Pulse.Custom.custom_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1058,
  serialized_end=2011,
)

_SCANPATTERN_PULSE = _descriptor.Descriptor(
  name='Pulse',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle_spacing', full_name='blickfeld.protocol.config.ScanPattern.Pulse.angle_spacing', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\030\003rad\342\265\030\003deg\351\265\030\266\224c\032\334\245L@\360\265\030\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='blickfeld.protocol.config.ScanPattern.Pulse.type', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_mode', full_name='blickfeld.protocol.config.ScanPattern.Pulse.frame_mode', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distortion_correction', full_name='blickfeld.protocol.config.ScanPattern.Pulse.distortion_correction', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='blickfeld.protocol.config.ScanPattern.Pulse.custom', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCANPATTERN_PULSE_CUSTOM, ],
  enum_types=[
    _SCANPATTERN_PULSE_TYPE,
    _SCANPATTERN_PULSE_FRAMEMODE,
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 2), (6, 7), (7, 8), ],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=2205,
)

_SCANPATTERN_FRAMERATE = _descriptor.Descriptor(
  name='FrameRate',
  full_name='blickfeld.protocol.config.ScanPattern.FrameRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.target', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\030\002Hz\360\265\030\002\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.maximum', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\030\002Hz\360\265\030\002\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_time_offset', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.reference_time_offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\030\001s\342\265\030\002ms\360\265\030\001\351\265\030\374\251\361\322MbP?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2208,
  serialized_end=2346,
)

_SCANPATTERN_FILTER_NOISE = _descriptor.Descriptor(
  name='Noise',
  full_name='blickfeld.protocol.config.ScanPattern.Filter.Noise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='blickfeld.protocol.config.ScanPattern.Filter.Noise.offset', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\000\000\000\000\000\000\000\000\211\265\030\000\000\000\000\000\000I@', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain', full_name='blickfeld.protocol.config.ScanPattern.Filter.Noise.gain', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\000\000\000\000\000\000\000\000\211\265\030\000\000\000\000\000\000\340?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='blickfeld.protocol.config.ScanPattern.Filter.Noise.enable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2730,
  serialized_end=2837,
)

_SCANPATTERN_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='blickfeld.protocol.config.ScanPattern.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_number_of_returns_per_point', full_name='blickfeld.protocol.config.ScanPattern.Filter.max_number_of_returns_per_point', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\000\000\000\000\000\000\360?\211\265\030\000\000\000\000\000\000\010@', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intensity', full_name='blickfeld.protocol.config.ScanPattern.Filter.intensity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ambient_light_level', full_name='blickfeld.protocol.config.ScanPattern.Filter.ambient_light_level', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='blickfeld.protocol.config.ScanPattern.Filter.range', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noise', full_name='blickfeld.protocol.config.ScanPattern.Filter.noise', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_points_without_returns', full_name='blickfeld.protocol.config.ScanPattern.Filter.delete_points_without_returns', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCANPATTERN_FILTER_NOISE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2349,
  serialized_end=2837,
)

_SCANPATTERN = _descriptor.Descriptor(
  name='ScanPattern',
  full_name='blickfeld.protocol.config.ScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontal', full_name='blickfeld.protocol.config.ScanPattern.horizontal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertical', full_name='blickfeld.protocol.config.ScanPattern.vertical', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pulse', full_name='blickfeld.protocol.config.ScanPattern.pulse', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_rate', full_name='blickfeld.protocol.config.ScanPattern.frame_rate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='blickfeld.protocol.config.ScanPattern.filter', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='blickfeld.protocol.config.ScanPattern.constraints', index=5,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCANPATTERN_HORIZONTAL, _SCANPATTERN_VERTICAL, _SCANPATTERN_PULSE, _SCANPATTERN_FRAMERATE, _SCANPATTERN_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(5, 6), (6, 7), ],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=2849,
)

_SCANPATTERN_HORIZONTAL.containing_type = _SCANPATTERN
_SCANPATTERN_VERTICAL.containing_type = _SCANPATTERN
_SCANPATTERN_PULSE_CUSTOM_DURATION.containing_type = _SCANPATTERN_PULSE_CUSTOM
_SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER_ANGLE.fields_by_name['enabled_triggers'].enum_type = _SCANPATTERN_PULSE_CUSTOM_TRIGGER
_SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER_ANGLE.containing_type = _SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER
_SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER.fields_by_name['angles'].message_type = _SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER_ANGLE
_SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER.containing_type = _SCANPATTERN_PULSE_CUSTOM
_SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER_POINT.fields_by_name['enabled_triggers'].enum_type = _SCANPATTERN_PULSE_CUSTOM_TRIGGER
_SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER_POINT.containing_type = _SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER
_SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER.fields_by_name['points'].message_type = _SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER_POINT
_SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER.containing_type = _SCANPATTERN_PULSE_CUSTOM
_SCANPATTERN_PULSE_CUSTOM.fields_by_name['angle_trigger'].message_type = _SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER
_SCANPATTERN_PULSE_CUSTOM.fields_by_name['point_trigger'].message_type = _SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER
_SCANPATTERN_PULSE_CUSTOM.fields_by_name['duration'].message_type = _SCANPATTERN_PULSE_CUSTOM_DURATION
_SCANPATTERN_PULSE_CUSTOM.containing_type = _SCANPATTERN_PULSE
_SCANPATTERN_PULSE_CUSTOM_TRIGGER.containing_type = _SCANPATTERN_PULSE_CUSTOM
_SCANPATTERN_PULSE_CUSTOM.oneofs_by_name['custom_type'].fields.append(
  _SCANPATTERN_PULSE_CUSTOM.fields_by_name['angle_trigger'])
_SCANPATTERN_PULSE_CUSTOM.fields_by_name['angle_trigger'].containing_oneof = _SCANPATTERN_PULSE_CUSTOM.oneofs_by_name['custom_type']
_SCANPATTERN_PULSE_CUSTOM.oneofs_by_name['custom_type'].fields.append(
  _SCANPATTERN_PULSE_CUSTOM.fields_by_name['point_trigger'])
_SCANPATTERN_PULSE_CUSTOM.fields_by_name['point_trigger'].containing_oneof = _SCANPATTERN_PULSE_CUSTOM.oneofs_by_name['custom_type']
_SCANPATTERN_PULSE.fields_by_name['type'].enum_type = _SCANPATTERN_PULSE_TYPE
_SCANPATTERN_PULSE.fields_by_name['frame_mode'].enum_type = _SCANPATTERN_PULSE_FRAMEMODE
_SCANPATTERN_PULSE.fields_by_name['custom'].message_type = _SCANPATTERN_PULSE_CUSTOM
_SCANPATTERN_PULSE.containing_type = _SCANPATTERN
_SCANPATTERN_PULSE_TYPE.containing_type = _SCANPATTERN_PULSE
_SCANPATTERN_PULSE_FRAMEMODE.containing_type = _SCANPATTERN_PULSE
_SCANPATTERN_FRAMERATE.containing_type = _SCANPATTERN
_SCANPATTERN_FILTER_NOISE.containing_type = _SCANPATTERN_FILTER
_SCANPATTERN_FILTER.fields_by_name['intensity'].message_type = blickfeld_dot_common__pb2._OPTIONALVALUERANGE
_SCANPATTERN_FILTER.fields_by_name['ambient_light_level'].message_type = blickfeld_dot_common__pb2._OPTIONALVALUERANGE
_SCANPATTERN_FILTER.fields_by_name['range'].message_type = blickfeld_dot_common__pb2._OPTIONALVALUERANGE
_SCANPATTERN_FILTER.fields_by_name['noise'].message_type = _SCANPATTERN_FILTER_NOISE
_SCANPATTERN_FILTER.containing_type = _SCANPATTERN
_SCANPATTERN.fields_by_name['horizontal'].message_type = _SCANPATTERN_HORIZONTAL
_SCANPATTERN.fields_by_name['vertical'].message_type = _SCANPATTERN_VERTICAL
_SCANPATTERN.fields_by_name['pulse'].message_type = _SCANPATTERN_PULSE
_SCANPATTERN.fields_by_name['frame_rate'].message_type = _SCANPATTERN_FRAMERATE
_SCANPATTERN.fields_by_name['filter'].message_type = _SCANPATTERN_FILTER
_SCANPATTERN.fields_by_name['constraints'].message_type = blickfeld_dot_common__pb2._CONSTRAINT
DESCRIPTOR.message_types_by_name['ScanPattern'] = _SCANPATTERN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScanPattern = _reflection.GeneratedProtocolMessageType('ScanPattern', (_message.Message,), {

  'Horizontal' : _reflection.GeneratedProtocolMessageType('Horizontal', (_message.Message,), {
    'DESCRIPTOR' : _SCANPATTERN_HORIZONTAL,
    '__module__' : 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Horizontal)
    })
  ,

  'Vertical' : _reflection.GeneratedProtocolMessageType('Vertical', (_message.Message,), {
    'DESCRIPTOR' : _SCANPATTERN_VERTICAL,
    '__module__' : 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Vertical)
    })
  ,

  'Pulse' : _reflection.GeneratedProtocolMessageType('Pulse', (_message.Message,), {

    'Custom' : _reflection.GeneratedProtocolMessageType('Custom', (_message.Message,), {

      'Duration' : _reflection.GeneratedProtocolMessageType('Duration', (_message.Message,), {
        'DESCRIPTOR' : _SCANPATTERN_PULSE_CUSTOM_DURATION,
        '__module__' : 'blickfeld.config.scan_pattern_pb2'
        # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse.Custom.Duration)
        })
      ,

      'AngleTrigger' : _reflection.GeneratedProtocolMessageType('AngleTrigger', (_message.Message,), {

        'Angle' : _reflection.GeneratedProtocolMessageType('Angle', (_message.Message,), {
          'DESCRIPTOR' : _SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER_ANGLE,
          '__module__' : 'blickfeld.config.scan_pattern_pb2'
          # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger.Angle)
          })
        ,
        'DESCRIPTOR' : _SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER,
        '__module__' : 'blickfeld.config.scan_pattern_pb2'
        # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse.Custom.AngleTrigger)
        })
      ,

      'PointTrigger' : _reflection.GeneratedProtocolMessageType('PointTrigger', (_message.Message,), {

        'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
          'DESCRIPTOR' : _SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER_POINT,
          '__module__' : 'blickfeld.config.scan_pattern_pb2'
          # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTrigger.Point)
          })
        ,
        'DESCRIPTOR' : _SCANPATTERN_PULSE_CUSTOM_POINTTRIGGER,
        '__module__' : 'blickfeld.config.scan_pattern_pb2'
        # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse.Custom.PointTrigger)
        })
      ,
      'DESCRIPTOR' : _SCANPATTERN_PULSE_CUSTOM,
      '__module__' : 'blickfeld.config.scan_pattern_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse.Custom)
      })
    ,
    'DESCRIPTOR' : _SCANPATTERN_PULSE,
    '__module__' : 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse)
    })
  ,

  'FrameRate' : _reflection.GeneratedProtocolMessageType('FrameRate', (_message.Message,), {
    'DESCRIPTOR' : _SCANPATTERN_FRAMERATE,
    '__module__' : 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.FrameRate)
    })
  ,

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {

    'Noise' : _reflection.GeneratedProtocolMessageType('Noise', (_message.Message,), {
      'DESCRIPTOR' : _SCANPATTERN_FILTER_NOISE,
      '__module__' : 'blickfeld.config.scan_pattern_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Filter.Noise)
      })
    ,
    'DESCRIPTOR' : _SCANPATTERN_FILTER,
    '__module__' : 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Filter)
    })
  ,
  'DESCRIPTOR' : _SCANPATTERN,
  '__module__' : 'blickfeld.config.scan_pattern_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern)
  })
_sym_db.RegisterMessage(ScanPattern)
_sym_db.RegisterMessage(ScanPattern.Horizontal)
_sym_db.RegisterMessage(ScanPattern.Vertical)
_sym_db.RegisterMessage(ScanPattern.Pulse)
_sym_db.RegisterMessage(ScanPattern.Pulse.Custom)
_sym_db.RegisterMessage(ScanPattern.Pulse.Custom.Duration)
_sym_db.RegisterMessage(ScanPattern.Pulse.Custom.AngleTrigger)
_sym_db.RegisterMessage(ScanPattern.Pulse.Custom.AngleTrigger.Angle)
_sym_db.RegisterMessage(ScanPattern.Pulse.Custom.PointTrigger)
_sym_db.RegisterMessage(ScanPattern.Pulse.Custom.PointTrigger.Point)
_sym_db.RegisterMessage(ScanPattern.FrameRate)
_sym_db.RegisterMessage(ScanPattern.Filter)
_sym_db.RegisterMessage(ScanPattern.Filter.Noise)


_SCANPATTERN_HORIZONTAL.fields_by_name['fov']._options = None
_SCANPATTERN_VERTICAL.fields_by_name['fov']._options = None
_SCANPATTERN_VERTICAL.fields_by_name['scanlines_up']._options = None
_SCANPATTERN_VERTICAL.fields_by_name['scanlines_down']._options = None
_SCANPATTERN_PULSE_CUSTOM_DURATION.fields_by_name['external_0']._options = None
_SCANPATTERN_PULSE_CUSTOM_DURATION.fields_by_name['external_1']._options = None
_SCANPATTERN_PULSE_CUSTOM_ANGLETRIGGER_ANGLE.fields_by_name['scanline_id']._options = None
_SCANPATTERN_PULSE.fields_by_name['angle_spacing']._options = None
_SCANPATTERN_PULSE.fields_by_name['custom']._options = None
_SCANPATTERN_FRAMERATE.fields_by_name['target']._options = None
_SCANPATTERN_FRAMERATE.fields_by_name['maximum']._options = None
_SCANPATTERN_FRAMERATE.fields_by_name['reference_time_offset']._options = None
_SCANPATTERN_FILTER_NOISE.fields_by_name['offset']._options = None
_SCANPATTERN_FILTER_NOISE.fields_by_name['gain']._options = None
_SCANPATTERN_FILTER.fields_by_name['max_number_of_returns_per_point']._options = None
_SCANPATTERN_FILTER.fields_by_name['noise']._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.config.scan_pattern_pb2
import blickfeld.error_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Scanner(google.protobuf.message.Message):
    """*
    This section defines the status of the device.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class State(_State, metaclass=_StateEnumTypeWrapper):
        pass
    class _State:
        V = typing.NewType('V', builtins.int)
    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_State.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        INITIALIZING = Scanner.State.V(1)
        """Device is initializing the hardware."""

        READY = Scanner.State.V(2)
        """Device is ready to start and no error occurred."""

        STARTING = Scanner.State.V(3)
        """Device is starting a point cloud recording, but is not yet recording."""

        RUNNING = Scanner.State.V(4)
        """Device is recording a point cloud."""

        STOPPING = Scanner.State.V(5)
        """Device stops point cloud recording; it is no longer recording."""

        ERRORED = Scanner.State.V(6)
        """Device is in an error state; it can no longer operate."""

        SELF_TESTING = Scanner.State.V(7)
        """Device is testing the hardware."""


    INITIALIZING = Scanner.State.V(1)
    """Device is initializing the hardware."""

    READY = Scanner.State.V(2)
    """Device is ready to start and no error occurred."""

    STARTING = Scanner.State.V(3)
    """Device is starting a point cloud recording, but is not yet recording."""

    RUNNING = Scanner.State.V(4)
    """Device is recording a point cloud."""

    STOPPING = Scanner.State.V(5)
    """Device stops point cloud recording; it is no longer recording."""

    ERRORED = Scanner.State.V(6)
    """Device is in an error state; it can no longer operate."""

    SELF_TESTING = Scanner.State.V(7)
    """Device is testing the hardware."""


    STATE_FIELD_NUMBER: builtins.int
    SCAN_PATTERN_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    state: global___Scanner.State.V = ...
    """Refer to [Scanner.State](#blickfeld.protocol.status.Scanner.State)"""

    @property
    def scan_pattern(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern:
        """Refer to [ScanPattern](#blickfeld.protocol.config.ScanPattern)"""
        pass
    @property
    def error(self) -> blickfeld.error_pb2.Error:
        """Refer to [Error](#blickfeld.protocol.Error)"""
        pass
    def __init__(self,
        *,
        state : typing.Optional[global___Scanner.State.V] = ...,
        scan_pattern : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
        error : typing.Optional[blickfeld.error_pb2.Error] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"error",b"error",u"scan_pattern",b"scan_pattern",u"state",b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"error",b"error",u"scan_pattern",b"scan_pattern",u"state",b"state"]) -> None: ...
global___Scanner = Scanner



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Axis(google.protobuf.message.Message):
    """*
    Axis of a coordinate system.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        pass
    class _Type:
        V = typing.NewType('V', builtins.int)
    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Type.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        X = Axis.Type.V(0)
        Y = Axis.Type.V(1)
        Z = Axis.Type.V(2)

    X = Axis.Type.V(0)
    Y = Axis.Type.V(1)
    Z = Axis.Type.V(2)

    TYPE_FIELD_NUMBER: builtins.int
    type: global___Axis.Type.V = ...
    def __init__(self,
        *,
        type : global___Axis.Type.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"type",b"type"]) -> None: ...
global___Axis = Axis

class Vector3(google.protobuf.message.Message):
    """*
    A vector with three components to represent a 3D coordiante.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    Z_FIELD_NUMBER: builtins.int
    x: builtins.float = ...
    """The X component."""

    y: builtins.float = ...
    """The Y component."""

    z: builtins.float = ...
    """The Z component."""

    def __init__(self,
        *,
        x : builtins.float = ...,
        y : builtins.float = ...,
        z : builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"x",b"x",u"y",b"y",u"z",b"z"]) -> None: ...
global___Vector3 = Vector3

class Quaternion(google.protobuf.message.Message):
    """*
    A quaternion for representing an orientation.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    Z_FIELD_NUMBER: builtins.int
    W_FIELD_NUMBER: builtins.int
    x: builtins.float = ...
    """The X component."""

    y: builtins.float = ...
    """The Y component."""

    z: builtins.float = ...
    """The Z component."""

    w: builtins.float = ...
    """The W component (real part)."""

    def __init__(self,
        *,
        x : builtins.float = ...,
        y : builtins.float = ...,
        z : builtins.float = ...,
        w : builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"w",b"w",u"x",b"x",u"y",b"y",u"z",b"z"]) -> None: ...
global___Quaternion = Quaternion

class Pose(google.protobuf.message.Message):
    """*
    A pose, consisting of a vector3 (3D coordinate) and a quaternion.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POSITION_FIELD_NUMBER: builtins.int
    ORIENTATION_FIELD_NUMBER: builtins.int
    @property
    def position(self) -> global___Vector3:
        """A vector representing the position."""
        pass
    @property
    def orientation(self) -> global___Quaternion:
        """A quaternion representing the orientation."""
        pass
    def __init__(self,
        *,
        position : typing.Optional[global___Vector3] = ...,
        orientation : typing.Optional[global___Quaternion] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"orientation",b"orientation",u"position",b"position"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"orientation",b"orientation",u"position",b"position"]) -> None: ...
global___Pose = Pose

class Transform(google.protobuf.message.Message):
    """*

    A rigid transformation
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TRANSLATION_FIELD_NUMBER: builtins.int
    ROTATION_FIELD_NUMBER: builtins.int
    @property
    def translation(self) -> global___Vector3: ...
    @property
    def rotation(self) -> global___Quaternion: ...
    def __init__(self,
        *,
        translation : typing.Optional[global___Vector3] = ...,
        rotation : typing.Optional[global___Quaternion] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"rotation",b"rotation",u"translation",b"translation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rotation",b"rotation",u"translation",b"translation"]) -> None: ...
global___Transform = Transform



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.config.scan_pattern_pb2
import blickfeld.data.algorithm_pb2
import blickfeld.data.scanline_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Frame(google.protobuf.message.Message):
    """*
    This section describes the contents of a point cloud frame.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Packed(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.16 and firmware v1.17

        This format returns point clouds as flat binary structures.
        These can be efficiently encoded & decoded, which increases the performance on low-performance clients significantly.
        The network bandwidth is usually slightly higher as the data is not encoded.

        Note:
        The reference frame concept is handled differently for packed structures.
        To activate the packed format, it is sufficient to set an empty packed message in the reference frame.
        The requested fields need to be selected in the scanlines structure.
        Refer to REF_FRAME_PACKED in the client implementations.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LENGTH_FIELD_NUMBER: builtins.int
        CARTESIAN_FIELD_NUMBER: builtins.int
        DIRECTION_FIELD_NUMBER: builtins.int
        RANGE_FIELD_NUMBER: builtins.int
        INTENSITY_FIELD_NUMBER: builtins.int
        AMBIENT_LIGHT_LEVEL_FIELD_NUMBER: builtins.int
        START_OFFSET_NS_FIELD_NUMBER: builtins.int
        POINT_ID_FIELD_NUMBER: builtins.int
        CHANNEL_ID_FIELD_NUMBER: builtins.int
        RETURN_ID_FIELD_NUMBER: builtins.int
        length: builtins.int = ...
        """Length of arrays"""

        cartesian: builtins.bytes = ...
        """Cartesian coordinates. 3-dimensional array in row-major format with [x, y, z] tuples. Unit: [m]. Type: Float32. Byte Order: Big Endian."""

        direction: builtins.bytes = ...
        """Polar coordinates. 2-dimensional array in row-major format with [azimuth, elevation] tuples. Unit: [rad]. Type: Float32. Byte Order: Big Endian."""

        range: builtins.bytes = ...
        """Distance to the return. 1-dimensional array. Unit: [m]. Type: Float32. Byte Order: Big Endian."""

        intensity: builtins.bytes = ...
        """Intensity of the returned laser pulse. 1-dimensional array. Type: UInt32. Byte Order: Big Endian."""

        ambient_light_level: builtins.bytes = ...
        """Ambient light level in the direction of the point. 1-dimensional array. Type: UInt32. Byte Order: Big Endian."""

        start_offset_ns: builtins.bytes = ...
        """Starting time of the point in relation to [Frame.start_time_ns](#blickfeld.protocol.data.Frame.start_time_ns). 1-dimensional array. Unit: [ns]. Type: UInt64. Byte Order: Big Endian."""

        point_id: builtins.bytes = ...
        """Unique point identifier within a frame and scan pattern. 1-dimensional array. Type: UInt32. Byte Order: Big Endian."""

        channel_id: builtins.bytes = ...
        """Identifier of the channel that detected the point. 1-dimensional array. Type: UInt8."""

        return_id: builtins.bytes = ...
        """Identifier of the return. Note: Returns are ordered by intensity not by distance. 1-dimensional array. Type: UInt8."""

        def __init__(self,
            *,
            length : typing.Optional[builtins.int] = ...,
            cartesian : typing.Optional[builtins.bytes] = ...,
            direction : typing.Optional[builtins.bytes] = ...,
            range : typing.Optional[builtins.bytes] = ...,
            intensity : typing.Optional[builtins.bytes] = ...,
            ambient_light_level : typing.Optional[builtins.bytes] = ...,
            start_offset_ns : typing.Optional[builtins.bytes] = ...,
            point_id : typing.Optional[builtins.bytes] = ...,
            channel_id : typing.Optional[builtins.bytes] = ...,
            return_id : typing.Optional[builtins.bytes] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"ambient_light_level",b"ambient_light_level",u"cartesian",b"cartesian",u"channel_id",b"channel_id",u"direction",b"direction",u"intensity",b"intensity",u"length",b"length",u"point_id",b"point_id",u"range",b"range",u"return_id",b"return_id",u"start_offset_ns",b"start_offset_ns"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"ambient_light_level",b"ambient_light_level",u"cartesian",b"cartesian",u"channel_id",b"channel_id",u"direction",b"direction",u"intensity",b"intensity",u"length",b"length",u"point_id",b"point_id",u"range",b"range",u"return_id",b"return_id",u"start_offset_ns",b"start_offset_ns"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    START_TIME_NS_FIELD_NUMBER: builtins.int
    SCAN_PATTERN_FIELD_NUMBER: builtins.int
    IS_RAMP_UP_PHASE_FIELD_NUMBER: builtins.int
    TOTAL_NUMBER_OF_POINTS_FIELD_NUMBER: builtins.int
    TOTAL_NUMBER_OF_RETURNS_FIELD_NUMBER: builtins.int
    SCANLINES_FIELD_NUMBER: builtins.int
    PACKED_FIELD_NUMBER: builtins.int
    ALGORITHMS_FIELD_NUMBER: builtins.int
    id: builtins.int = ...
    """Incremental frame ID since startup of the device"""

    start_time_ns: builtins.int = ...
    """Unit: [s] – start frame timestamp"""

    @property
    def scan_pattern(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern:
        """Refer to [ScanPattern](#blickfeld.protocol.config.ScanPattern)"""
        pass
    is_ramp_up_phase: builtins.bool = ...
    """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> If the frame_mode in the scan pattern is set to SEPARATE, this value indicates if the given frame was captured during up-ramping or down-ramping."""

    total_number_of_points: builtins.int = ...
    """Number of laser pulses emitted in this frame."""

    total_number_of_returns: builtins.int = ...
    """Number of returned points recorded: Each point of the [total_number_of_points](#blickfeld.protocol.data.Frame.total_number_of_points) can produce several returns."""

    @property
    def scanlines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.data.scanline_pb2.Scanline]:
        """Refer to [Scanline](#blickfeld.protocol.data.Scanline)"""
        pass
    @property
    def packed(self) -> global___Frame.Packed:
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Refer to [Packed](#blickfeld.protocol.data.Frame.Packed)"""
        pass
    @property
    def algorithms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.data.algorithm_pb2.Algorithm]:
        """<blockquote>Introduced in BSL v2.17 and firmware v1.16</blockquote> Refer to [data.Algorithm](#blickfeld.protocol.data.Algorithm). Each algorithm configured can output additional data, which is provided with this field."""
        pass
    def __init__(self,
        *,
        id : typing.Optional[builtins.int] = ...,
        start_time_ns : typing.Optional[builtins.int] = ...,
        scan_pattern : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
        is_ramp_up_phase : typing.Optional[builtins.bool] = ...,
        total_number_of_points : typing.Optional[builtins.int] = ...,
        total_number_of_returns : typing.Optional[builtins.int] = ...,
        scanlines : typing.Optional[typing.Iterable[blickfeld.data.scanline_pb2.Scanline]] = ...,
        packed : typing.Optional[global___Frame.Packed] = ...,
        algorithms : typing.Optional[typing.Iterable[blickfeld.data.algorithm_pb2.Algorithm]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"id",b"id",u"is_ramp_up_phase",b"is_ramp_up_phase",u"packed",b"packed",u"scan_pattern",b"scan_pattern",u"start_time_ns",b"start_time_ns",u"total_number_of_points",b"total_number_of_points",u"total_number_of_returns",b"total_number_of_returns"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"algorithms",b"algorithms",u"id",b"id",u"is_ramp_up_phase",b"is_ramp_up_phase",u"packed",b"packed",u"scan_pattern",b"scan_pattern",u"scanlines",b"scanlines",u"start_time_ns",b"start_time_ns",u"total_number_of_points",b"total_number_of_points",u"total_number_of_returns",b"total_number_of_returns"]) -> None: ...
global___Frame = Frame



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.data.frame_pb2
import blickfeld.data.scanline_pb2
import blickfeld.stream.connection_pb2
import blickfeld.update.hardware_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PointCloud(google.protobuf.message.Message):
    """*
    A point cloud object can contain either a full frame or a single scan line.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Header(google.protobuf.message.Message):
        """*
        This section describes the contents of a point cloud header.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LEGACY_CUBE_SERIAL_NUMBER_FIELD_NUMBER: builtins.int
        CUBE_SERIAL_NUMBER_FIELD_NUMBER: builtins.int
        START_TIME_NS_FIELD_NUMBER: builtins.int
        FIRMWARE_VERSION_FIELD_NUMBER: builtins.int
        HARDWARE_VARIANT_FIELD_NUMBER: builtins.int
        SUBSCRIPTION_FIELD_NUMBER: builtins.int
        legacy_cube_serial_number: typing.Text = ...
        """Legacy serial number of the device which recorded the pointcloud"""

        cube_serial_number: typing.Text = ...
        """Serial number of the device which recorded the pointcloud"""

        start_time_ns: builtins.int = ...
        """Unit: [s] - Start timestamp of the requested pointcloud stream"""

        firmware_version: typing.Text = ...
        """Firmware version of the device which recorded the pointcloud"""

        hardware_variant: blickfeld.update.hardware_pb2.HardwareVariant.V = ...
        """Hardware variant of the device which recorded the pointcloud"""

        @property
        def subscription(self) -> blickfeld.stream.connection_pb2.Subscribe.PointCloud:
            """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Used & merged subscription for stream"""
            pass
        def __init__(self,
            *,
            legacy_cube_serial_number : typing.Optional[typing.Text] = ...,
            cube_serial_number : typing.Optional[typing.Text] = ...,
            start_time_ns : typing.Optional[builtins.int] = ...,
            firmware_version : typing.Optional[typing.Text] = ...,
            hardware_variant : typing.Optional[blickfeld.update.hardware_pb2.HardwareVariant.V] = ...,
            subscription : typing.Optional[blickfeld.stream.connection_pb2.Subscribe.PointCloud] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"cube_serial_number",b"cube_serial_number",u"firmware_version",b"firmware_version",u"hardware_variant",b"hardware_variant",u"legacy_cube_serial_number",b"legacy_cube_serial_number",u"start_time_ns",b"start_time_ns",u"subscription",b"subscription"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"cube_serial_number",b"cube_serial_number",u"firmware_version",b"firmware_version",u"hardware_variant",b"hardware_variant",u"legacy_cube_serial_number",b"legacy_cube_serial_number",u"start_time_ns",b"start_time_ns",u"subscription",b"subscription"]) -> None: ...

    HEADER_FIELD_NUMBER: builtins.int
    FRAME_FIELD_NUMBER: builtins.int
    SCANLINE_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> global___PointCloud.Header:
        """Refer to [PointCloud.Header](#blickfeld.protocol.data.PointCloud.Header)"""
        pass
    @property
    def frame(self) -> blickfeld.data.frame_pb2.Frame:
        """Refer to [Frame](#blickfeld.protocol.data.Frame)"""
        pass
    @property
    def scanline(self) -> blickfeld.data.scanline_pb2.Scanline:
        """Refer to [Scanline](#blickfeld.protocol.data.Scanline)"""
        pass
    def __init__(self,
        *,
        header : typing.Optional[global___PointCloud.Header] = ...,
        frame : typing.Optional[blickfeld.data.frame_pb2.Frame] = ...,
        scanline : typing.Optional[blickfeld.data.scanline_pb2.Scanline] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"frame",b"frame",u"header",b"header",u"scanline",b"scanline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"frame",b"frame",u"header",b"header",u"scanline",b"scanline"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing.Optional[typing_extensions.Literal["header","frame","scanline"]]: ...
global___PointCloud = PointCloud



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.config.scan_pattern_pb2
import blickfeld.data.frame_pb2
import blickfeld.data.point_cloud_pb2
import blickfeld.file.general_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PointCloud(google.protobuf.message.Message):
    """*
    This section describes the contents of a point cloud. The first message in a Blickfeld protobuf pointcloud should always be the
    [PointCloud.Header](#blickfeld.protocol.data.PointCloud.Header) message followed by [PointCloud.Data](#blickfeld.protocol.data.PointCloud.Data) messages.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Header(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DEVICE_FIELD_NUMBER: builtins.int
        CLIENT_FIELD_NUMBER: builtins.int
        @property
        def device(self) -> blickfeld.data.point_cloud_pb2.PointCloud.Header:
            """Refer to [PointCloud.Header](#blickfeld.protocol.data.PointCloud.Header)"""
            pass
        @property
        def client(self) -> blickfeld.file.general_pb2.Client: ...
        def __init__(self,
            *,
            device : typing.Optional[blickfeld.data.point_cloud_pb2.PointCloud.Header] = ...,
            client : typing.Optional[blickfeld.file.general_pb2.Client] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"client",b"client",u"device",b"device"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"client",b"client",u"device",b"device"]) -> None: ...

    class Footer(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Stats(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            class Counter(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
                FRAMES_FIELD_NUMBER: builtins.int
                POINTS_FIELD_NUMBER: builtins.int
                RETURNS_FIELD_NUMBER: builtins.int
                frames: builtins.int = ...
                points: builtins.int = ...
                returns: builtins.int = ...
                def __init__(self,
                    *,
                    frames : typing.Optional[builtins.int] = ...,
                    points : typing.Optional[builtins.int] = ...,
                    returns : typing.Optional[builtins.int] = ...,
                    ) -> None: ...
                def HasField(self, field_name: typing_extensions.Literal[u"frames",b"frames",u"points",b"points",u"returns",b"returns"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing_extensions.Literal[u"frames",b"frames",u"points",b"points",u"returns",b"returns"]) -> None: ...

            COUNTER_FIELD_NUMBER: builtins.int
            @property
            def counter(self) -> global___PointCloud.Footer.Stats.Counter: ...
            def __init__(self,
                *,
                counter : typing.Optional[global___PointCloud.Footer.Stats.Counter] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"counter",b"counter"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"counter",b"counter"]) -> None: ...

        class Event(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            FROM_FRAME_ID_FIELD_NUMBER: builtins.int
            SCAN_PATTERN_FIELD_NUMBER: builtins.int
            from_frame_id: builtins.int = ...
            @property
            def scan_pattern(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern: ...
            def __init__(self,
                *,
                from_frame_id : typing.Optional[builtins.int] = ...,
                scan_pattern : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"from_frame_id",b"from_frame_id",u"scan_pattern",b"scan_pattern"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"from_frame_id",b"from_frame_id",u"scan_pattern",b"scan_pattern"]) -> None: ...

        STATS_FIELD_NUMBER: builtins.int
        EVENTS_FIELD_NUMBER: builtins.int
        STOP_TIME_NS_FIELD_NUMBER: builtins.int
        @property
        def stats(self) -> global___PointCloud.Footer.Stats: ...
        @property
        def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PointCloud.Footer.Event]: ...
        stop_time_ns: builtins.int = ...
        """Unit: [ns] - Stop timestamp of the requested pointcloud stream"""

        def __init__(self,
            *,
            stats : typing.Optional[global___PointCloud.Footer.Stats] = ...,
            events : typing.Optional[typing.Iterable[global___PointCloud.Footer.Event]] = ...,
            stop_time_ns : typing.Optional[builtins.int] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"stats",b"stats",u"stop_time_ns",b"stop_time_ns"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"events",b"events",u"stats",b"stats",u"stop_time_ns",b"stop_time_ns"]) -> None: ...

    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        HEADER_FIELD_NUMBER: builtins.int
        FOOTER_FIELD_NUMBER: builtins.int
        @property
        def header(self) -> global___PointCloud.Header: ...
        @property
        def footer(self) -> global___PointCloud.Footer: ...
        def __init__(self,
            *,
            header : typing.Optional[global___PointCloud.Header] = ...,
            footer : typing.Optional[global___PointCloud.Footer] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"footer",b"footer",u"header",b"header"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"footer",b"footer",u"header",b"header"]) -> None: ...

    class Data(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FRAME_FIELD_NUMBER: builtins.int
        FOOTER_FIELD_NUMBER: builtins.int
        @property
        def frame(self) -> blickfeld.data.frame_pb2.Frame:
            """Refer to [PointCloud](#blickfeld.protocol.data.Frame)"""
            pass
        @property
        def footer(self) -> global___PointCloud.Footer: ...
        def __init__(self,
            *,
            frame : typing.Optional[blickfeld.data.frame_pb2.Frame] = ...,
            footer : typing.Optional[global___PointCloud.Footer] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"footer",b"footer",u"frame",b"frame"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"footer",b"footer",u"frame",b"frame"]) -> None: ...

    def __init__(self,
        ) -> None: ...
global___PointCloud = PointCloud



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Algorithm(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.17 and firmware v1.18

    This section describes configuration of on-device algorithms.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class BackgroundSubtraction(google.protobuf.message.Message):
        """*
        > Introduced in firmware v1.16

        This message configures the background subtraction.

        The algorithm uses a configurable number of reference frames to estimate static points (background) in the scene.
        Once the number of reference frames are processed, it removes all static points from the point cloud output.
        The resulting point cloud then only contains the non-static points (foreground).
        Points that are a initially part of the foreground and but then stop moving, will be added to the background and
        thus disappear after a certain amount of time, which is given by the exponential decay rate parameter.
        Conversely, if an object that is already part of the background suddenly starts moving, it will be added to the foreground.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        INITIALIZATION_FRAMES_FIELD_NUMBER: builtins.int
        EXPONENTIAL_DECAY_RATE_FIELD_NUMBER: builtins.int
        initialization_frames: builtins.int = ...
        """Number of frames to initialize the background with"""

        exponential_decay_rate: builtins.float = ...
        """Controls how fast objects switch between foreground and background. Exponential decay factor."""

        def __init__(self,
            *,
            initialization_frames : typing.Optional[builtins.int] = ...,
            exponential_decay_rate : typing.Optional[builtins.float] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"exponential_decay_rate",b"exponential_decay_rate",u"initialization_frames",b"initialization_frames"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"exponential_decay_rate",b"exponential_decay_rate",u"initialization_frames",b"initialization_frames"]) -> None: ...

    class NeighborFilter(google.protobuf.message.Message):
        """*
        > Introduced in firmware v1.18

        The neighbor filter is a simple noise filter, which uses neighboring returns in the scan pattern to decide if returns should be filtered.

        The algorithm iterates through all returns and removes all, which have zero neighbors.
        A neighbor return must be:
        - directly to the left / to the right / above / below the current return in the scan pattern
        - close to the current return. The maximum range, used for this condition, is defined by the angle spacing of the scan pattern and the range of the current return. As with higher distance, neighboring returns are expected to be further away.

        No parameters can be configured at the moment.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class StaticTransformation(google.protobuf.message.Message):
        """*

        > Introduced in firmware v1.18

        This message configures a static geometric transformation.

        The algorithm applies a static rotation and translation to the point cloud output.

        The rotation matrix **R** is expected to be a 3 x 3 matrix serialized in row major order.

        Rotation in matrix representation:

        |     |  R  |     |
        | --- | --- | --- |
        | r<sub>1,1</sub> | r<sub>1,2</sub> | r<sub>1,3</sub> |
        | r<sub>2,1</sub> | r<sub>2,2</sub> | r<sub>2,3</sub> |
        | r<sub>3,1</sub> | r<sub>3,2</sub> | r<sub>3,3</sub> |

        Rotation in serialized representation:

        **R** = [r<sub>1,1</sub>, r<sub>1,2</sub>, ... r<sub>3,2</sub>, r<sub>3,3</sub>]

        The translation vector **T** is expected to be a 3 x 1 vector.

        Translation in vector representation:

        |  T  |
        | --- |
        |  t<sub>1</sub>  |
        |  t<sub>2</sub>  |
        |  t<sub>3</sub>  |

        Translation in serialized representation:

        **T** = [t<sub>1</sub>, t<sub>2</sub>, t<sub>3</sub>] =  [x, y, z]
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ROTATION_MATRIX_FIELD_NUMBER: builtins.int
        TRANSLATION_VECTOR_FIELD_NUMBER: builtins.int
        @property
        def rotation_matrix(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """rotation matrix **R** in serialized representation."""
            pass
        @property
        def translation_vector(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """translation vector **T** in serialized representation."""
            pass
        def __init__(self,
            *,
            rotation_matrix : typing.Optional[typing.Iterable[builtins.float]] = ...,
            translation_vector : typing.Optional[typing.Iterable[builtins.float]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"rotation_matrix",b"rotation_matrix",u"translation_vector",b"translation_vector"]) -> None: ...

    BACKGROUND_SUBTRACTION_FIELD_NUMBER: builtins.int
    NEIGHBOR_FILTER_FIELD_NUMBER: builtins.int
    STATIC_TRANSFORMATION_FIELD_NUMBER: builtins.int
    @property
    def background_subtraction(self) -> global___Algorithm.BackgroundSubtraction:
        """Refer to [BackgroundSubtraction](#blickfeld.protocol.config.Algorithm.BackgroundSubtraction)"""
        pass
    @property
    def neighbor_filter(self) -> global___Algorithm.NeighborFilter:
        """Refer to [NeighborFilter](#blickfeld.protocol.config.Algorithm.NeighborFilter)"""
        pass
    @property
    def static_transformation(self) -> global___Algorithm.StaticTransformation:
        """Refer to [StaticTransformation](#blickfeld.protocol.config.Algorithm.StaticTransformation)"""
        pass
    def __init__(self,
        *,
        background_subtraction : typing.Optional[global___Algorithm.BackgroundSubtraction] = ...,
        neighbor_filter : typing.Optional[global___Algorithm.NeighborFilter] = ...,
        static_transformation : typing.Optional[global___Algorithm.StaticTransformation] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"algo",b"algo",u"background_subtraction",b"background_subtraction",u"neighbor_filter",b"neighbor_filter",u"static_transformation",b"static_transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"algo",b"algo",u"background_subtraction",b"background_subtraction",u"neighbor_filter",b"neighbor_filter",u"static_transformation",b"static_transformation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"algo",b"algo"]) -> typing.Optional[typing_extensions.Literal["background_subtraction","neighbor_filter","static_transformation"]]: ...
global___Algorithm = Algorithm
